==> everycomp-1.20-2.8.7-fabric-sources.jar: net/mehvahdjukaar/every_compat/common_classes/CompatChestBlockEntity.java <==
package net.mehvahdjukaar.every_compat.common_classes;

import net.mehvahdjukaar.moonlight.api.platform.ClientHelper;
import net.mehvahdjukaar.moonlight.api.set.wood.WoodType;
import net.mehvahdjukaar.moonlight.api.set.wood.WoodTypeRegistry;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2561;
import net.minecraft.class_2591;
import net.minecraft.class_2595;
import net.minecraft.class_2680;

public class CompatChestBlockEntity extends class_2595 {
    private final WoodType woodType;
    private final boolean trapped;

    public CompatChestBlockEntity(class_2591<?> arg, class_2338 pos, class_2680 state) {
        super(arg, pos, state);
        var w = WoodTypeRegistry.INSTANCE.getBlockTypeOf(state.method_26204());
        this.woodType = w == null ? WoodTypeRegistry.OAK_TYPE : w;
        this.trapped = state.method_26204() instanceof CompatTrappedChestBlock;
    }

    public WoodType getWoodType() {
        return woodType;
    }

    @Override
    protected void method_11049(class_1937 level, class_2338 pos, class_2680 state, int eventId, int eventParam) {
        super.method_11049(level, pos, state, eventId, eventParam);
        if (trapped && eventId != eventParam) {
            class_2248 block = state.method_26204();
            level.method_8452(pos, block);
            level.method_8452(pos.method_10074(), block);
        }
    }

    public boolean isTrapped() {
        return trapped;
    }

    @Override
    protected class_2561 method_17823() {
        return class_2561.method_43469("container.everycomp.chest.name", class_2561.method_43471(woodType.getTranslationKey()).getString());
    }
}

==> everycomp-1.20-2.9.9-fabric-sources.jar: net/mehvahdjukaar/every_compat/common_classes/CompatChestBlockEntity.java <==
package net.mehvahdjukaar.every_compat.common_classes;

import net.mehvahdjukaar.moonlight.api.set.wood.VanillaWoodTypes;
import net.mehvahdjukaar.moonlight.api.set.wood.WoodType;
import net.mehvahdjukaar.moonlight.api.set.wood.WoodTypeRegistry;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2561;
import net.minecraft.class_2591;
import net.minecraft.class_2595;
import net.minecraft.class_2680;

public class CompatChestBlockEntity extends class_2595 {
    private final WoodType woodType;
    private final boolean trapped;

    public CompatChestBlockEntity(class_2591<?> blockEntityType, class_2338 pos, class_2680 state) {
        super(blockEntityType, pos, state);
        var w = WoodTypeRegistry.INSTANCE.getBlockTypeOf(state.method_26204());
        this.woodType = w == null ? VanillaWoodTypes.OAK : w;
        this.trapped = state.method_26204() instanceof CompatTrappedChestBlock;
    }

    public WoodType getWoodType() {
        return woodType;
    }

    @Override
    protected void method_11049(class_1937 level, class_2338 pos, class_2680 state, int eventId, int eventParam) {
        super.method_11049(level, pos, state, eventId, eventParam);
        if (trapped && eventId != eventParam) {
            class_2248 block = state.method_26204();
            level.method_8452(pos, block);
            level.method_8452(pos.method_10074(), block);
        }
    }

    public boolean isTrapped() {
        return trapped;
    }

    @Override
    protected class_2561 method_17823() {
        return class_2561.method_43469("container.everycomp.chest.name", class_2561.method_43471(woodType.getTranslationKey()).getString());
    }
}
